HrkDimensions class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bodyItemBorderWidth → const double
- bodyItemBoxWidth → const double
- bodyItemContentWidth → const double
- bodyItemMargin → const double
- bodyItemPadding → const double
- bodyItemSpacing → const double
- bodyItemWidth → const double
- containerRadius → const double
- gridItemBoxWidth → const double
- gridItemContentSize → const double
- gridItemWidth → const double
- pageMargin → const double
- pageMarginHorizontal → const double
- pageMarginHorizontalHalf → const double
- pageMarginVertical → const double
- pageMarginVerticalHalf → const double