LabelLinkInkWellWrap class

A Widget which displays Label with URI Link.

The Link part offers native web experience with the help of Link widget from the url_launcher package, like:

  • Displaying URI on the bottom left in the Chrome when the cursor is hovered on the URI
  • Context menu on right-click

The Label and the Link part is wrapped when sufficient width is not available, which helps in the widget not overflowing.

The Link part shows platform specific effect on interaction with the help of InkWell widget.

Inheritance

Constructors

LabelLinkInkWellWrap({Key? key, Key? labelKey, required String label, Key? linkKey, required Uri uri, PreFollowLink? preFollowLink, CustomFollowLink? customFollowLink})
const

Properties

final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
labelKey Key?
final
linkKey Key?
final
Can be used for the Analytics usages before followLink or customFollowLink
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited