LocaleListJsonConverter class

Locale list json converter for Nullable

See LocaleListJsonConverter2 for non-nullable

Constructors

LocaleListJsonConverter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(List? jsonList) List<Locale>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(List<Locale>? localeList) List<JsonMap>?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited