hrk_flutter_batteries library
Classes
- BodyItemContainer
- Container for body items
-
ChoiceChipGroup<
T> - ChoiceChip Group for single select. Use FilterChipGroup for multiple select.
-
ChoiceChipInputWidget<
T> - A widget to take input by selecting ChoiceChip and entering relevant data in TextField
- DateRangeWidget
- Widget to select start and end date using showDateRangePicker and displays them using dateFormat
- DeferredLoadingPlaceholder
- Displays a progress indicator and text description explaining that the widget is a deferred component and is currently being installed.
- DeferredWidget
- Wraps the child inside a deferred module loader.
- DeviceDimensions
-
FilterChipGroup<
T> - FilterChip Group for multiple select. Use ChoiceChipGroup for single select.
- HrkColors
- HrkDimensions
- LabelLinkInkWellWrap
- A Widget which displays Label with URI Link.
- LabelValueWrap
- A widget to display label and its value, if it doesn't fit in the same line then it is displayed in 2 lines but label with TextAlign.start and value with TextAlign.end
- LocaleJsonConverter
- Locale json converter for Nullable
- LocaleJsonConverter2
- Locale json converter for Non-nullable
- LocaleListJsonConverter
- Locale list json converter for Nullable
- LocaleListJsonConverter2
- Locale list json converter for Non-nullable
-
RadioDialog<
T> -
RadioSettingsTile<
T>
Enums
- DateRange
- StateMethod
- To identify invocation from State methods
Extensions
Functions
-
getLargestTextWidth(
{required BuildContext context, required Set< String> textSet, TextStyle? style, TextScaler? textScaler}) → double -
getTextPainterLaidout(
{required BuildContext context, required String text, TextStyle? style, TextScaler? textScaler}) → TextPainter
Typedefs
-
ChipSelected<
T> = void Function(T? value) -
ChipsSelected<
T> = void Function(Set< T> selectedSet) -
ChoiceChipInputChanged<
T> = void Function(T? value, List< String> textList) -
CustomFollowLink
= Future<
void> Function() -
DateRangeSelected
= void Function(DateTimeRange<
DateTime> ? dateTimeRange) - DeferredWidgetBuilder = Widget Function()
-
LibraryLoader
= Future<
void> Function() -
PreFollowLink
= Future<
void> Function() -
RadioListTileSelected<
T> = void Function(T value, int index)